@@ -33,6 +33,7 @@ THE SOFTWARE
 #include "OgreTextureUnitState.h"
 #include "OgreTechnique.h"
 #include "OgreBitwise.h"
+#include "OgreOverlayManager.h"
 
 #include "utf8.h"
 #include "OgreBillboardSet.h"
@@ -310,6 +311,7 @@ namespace Ogre
         if (mTexture->hasAlpha())
         {
             mMaterial->setSceneBlending( SBT_TRANSPARENT_ALPHA );
+            mMaterial->getTechnique(0)->getPass(0)->setTransparentSortingEnabled(false);
         }
         else
         {
@@ -357,6 +359,7 @@ namespace Ogre
         {
             mCodePointRangeList.push_back(CodePointRange(33, 126));
         }
+        float vpScale = OverlayManager::getSingleton().getPixelRatio();
 #ifdef HAVE_FREETYPE
         // ManualResourceLoader implementation - load the texture
         FT_Library ftLibrary;
@@ -375,9 +378,8 @@ namespace Ogre
 
         // Convert our point size to freetype 26.6 fixed point format
         FT_F26Dot6 ftSize = (FT_F26Dot6)(mTtfSize * (1 << 6));
-        if( FT_Set_Char_Size( face, ftSize, 0, mTtfResolution, mTtfResolution ) )
-            OGRE_EXCEPT( Exception::ERR_INTERNAL_ERROR,
-            "Could not set char size!", "Font::createTextureFromFont" );
+        if (FT_Set_Char_Size(face, ftSize, 0, mTtfResolution * vpScale, mTtfResolution * vpScale))
+            OGRE_EXCEPT(Exception::ERR_INTERNAL_ERROR, "Could not set char size!");
 
         //FILE *fo_def = stdout;
 
@@ -401,7 +403,7 @@ namespace Ogre
         stbtt_fontinfo font;
         stbtt_InitFont(&font, ttfchunk.getPtr(), 0);
         // 64 gives the same texture resolution as freetype.
-        float scale = stbtt_ScaleForPixelHeight(&font, mTtfSize * mTtfResolution / 64);
+        float scale = stbtt_ScaleForPixelHeight(&font, vpScale * mTtfSize * mTtfResolution / 64);
 
         int max_width = 0, max_height = 0;
         // Calculate maximum width, height and bearing
@@ -637,9 +639,8 @@ namespace Ogre
         Font* f = static_cast<Font*>(target);
 
         StringVector vec = StringUtil::split(val, " \t");
-        for (StringVector::iterator i = vec.begin(); i != vec.end(); ++i)
+        for (auto & item : vec)
         {
-            String& item = *i;
             StringVector itemVec = StringUtil::split(item, "-");
             if (itemVec.size() == 2)
             {
