@@ -189,11 +189,11 @@ void LayeredBlending::addPSBlendInvocations(Function* psMain,
     {
         //find the function name for the blend mode
         const char* funcName = NULL;
-        for(int i = 0 ; i < (int)LayeredBlending::LB_MaxBlendModes ; ++i)
+        for(const auto & _blendMode : _blendModes)
         {
-            if (_blendModes[i].type == mode)
+            if (_blendMode.type == mode)
             {
-                funcName = _blendModes[i].funcName;
+                funcName = _blendMode.funcName;
                 break;
             }
         }
@@ -447,11 +447,11 @@ SubRenderState* LayeredBlendingFactory::createInstanceImpl()
 //-----------------------------------------------------------------------
 LayeredBlending::BlendMode LayeredBlendingFactory::stringToBlendMode(const String &strValue)
 {
-    for(int i = 0 ; i < (int)LayeredBlending::LB_MaxBlendModes ; ++i)
+    for(const auto & _blendMode : _blendModes)
     {
-        if (_blendModes[i].name == strValue)
+        if (_blendMode.name == strValue)
         {
-            return _blendModes[i].type;
+            return _blendMode.type;
         }
     }
     return LayeredBlending::LB_Invalid;
@@ -460,11 +460,11 @@ LayeredBlending::BlendMode LayeredBlendingFactory::stringToBlendMode(const Strin
 //-----------------------------------------------------------------------
 String LayeredBlendingFactory::blendModeToString(LayeredBlending::BlendMode blendMode)
 {
-    for(int i = 0 ; i < (int)LayeredBlending::LB_MaxBlendModes ; ++i)
+    for(const auto & _blendMode : _blendModes)
     {
-        if (_blendModes[i].type == blendMode)
+        if (_blendMode.type == blendMode)
         {
-            return _blendModes[i].name;
+            return _blendMode.name;
         }
     }
     return "";
@@ -473,11 +473,11 @@ String LayeredBlendingFactory::blendModeToString(LayeredBlending::BlendMode blen
 //-----------------------------------------------------------------------
 LayeredBlending::SourceModifier LayeredBlendingFactory::stringToSourceModifier(const String &strValue)
 {
-    for(int i = 0 ; i < (int)LayeredBlending::SM_MaxSourceModifiers ; ++i)
+    for(const auto & _sourceModifier : _sourceModifiers)
     {
-        if (_sourceModifiers[i].name == strValue)
+        if (_sourceModifier.name == strValue)
         {
-            return _sourceModifiers[i].type;
+            return _sourceModifier.type;
         }
     }
     return LayeredBlending::SM_Invalid;
@@ -486,11 +486,11 @@ LayeredBlending::SourceModifier LayeredBlendingFactory::stringToSourceModifier(c
 //-----------------------------------------------------------------------
 String LayeredBlendingFactory::sourceModifierToString(LayeredBlending::SourceModifier modifier)
 {
-    for(int i = 0 ; i < (int)LayeredBlending::SM_MaxSourceModifiers ; ++i)
+    for(const auto & _sourceModifier : _sourceModifiers)
     {
-        if (_sourceModifiers[i].type == modifier)
+        if (_sourceModifier.type == modifier)
         {
-            return _sourceModifiers[i].name;
+            return _sourceModifier.name;
         }
     }
     return "";
