@@ -58,9 +58,9 @@ int FFPTexturing::getExecutionOrder() const
 //-----------------------------------------------------------------------
 bool FFPTexturing::resolveParameters(ProgramSet* programSet)
 {
-    for (unsigned int i=0; i < mTextureUnitParamsList.size(); ++i)
+    for (auto & i : mTextureUnitParamsList)
     {
-        TextureUnitParams* curParams = &mTextureUnitParamsList[i];
+        TextureUnitParams* curParams = &i;
 
         if (false == resolveUniformParams(curParams, programSet))
             return false;
@@ -233,9 +233,9 @@ bool FFPTexturing::addFunctionInvocations(ProgramSet* programSet)
     Function* vsMain   = vsProgram->getEntryPointFunction();
     Function* psMain   = psProgram->getEntryPointFunction();
 
-    for (unsigned int i=0; i < mTextureUnitParamsList.size(); ++i)
+    for (auto & i : mTextureUnitParamsList)
     {
-        TextureUnitParams* curParams = &mTextureUnitParamsList[i];
+        TextureUnitParams* curParams = &i;
 
         if (false == addVSFunctionInvocations(curParams, vsMain))
             return false;
