@@ -33,10 +33,17 @@ namespace RTShader {
 String GLSLProgramWriter::TargetLanguage = "glsl";
 
 //-----------------------------------------------------------------------
-GLSLProgramWriter::GLSLProgramWriter() : mIsGLSLES(false)
+GLSLProgramWriter::GLSLProgramWriter() : mIsGLSLES(false), mIsVulkan(false)
 {
     auto* rs = Root::getSingleton().getRenderSystem();
     mGLSLVersion = rs ? rs->getNativeShadingLanguageVersion() : 120;
+
+    if(rs && rs->getCapabilities()->isShaderProfileSupported("spirv"))
+    {
+        mGLSLVersion = 460;
+        mIsVulkan = true;
+    }
+
     initializeStringMaps();
 }
 
@@ -97,11 +104,8 @@ void GLSLProgramWriter::initializeStringMaps()
     mContentToPerVertexAttributes[Parameter::SPC_TEXTURE_COORDINATE6] = "uv6";
     mContentToPerVertexAttributes[Parameter::SPC_TEXTURE_COORDINATE7] = "uv7";  
 
-    if (mGLSLVersion >= 130 || mIsGLSLES)
-    {
-        mContentToPerVertexAttributes[Parameter::SPC_COLOR_DIFFUSE] = "colour";
-        mContentToPerVertexAttributes[Parameter::SPC_COLOR_SPECULAR] = "secondary_colour";
-    }
+    mContentToPerVertexAttributes[Parameter::SPC_COLOR_DIFFUSE] = "colour";
+    mContentToPerVertexAttributes[Parameter::SPC_COLOR_SPECULAR] = "secondary_colour";
 }
 
 //-----------------------------------------------------------------------
@@ -117,6 +121,22 @@ void GLSLProgramWriter::writeSourceCode(std::ostream& os, Program* program)
     writeMainSourceCode(os, program);
 }
 
+void GLSLProgramWriter::writeUniformBlock(std::ostream& os, const String& name, int binding,
+                                          const UniformParameterList& uniforms)
+{
+    os << "layout(binding = " << binding << ", row_major) uniform " << name << " {";
+
+    for (const auto& uparam : uniforms)
+    {
+        if(uparam->getType() == GCT_MATRIX_3X4 || uparam->getType() == GCT_MATRIX_2X4)
+            os << "layout(column_major) ";
+        writeParameter(os, uparam);
+        os << ";\n";
+    }
+
+    os << "\n};\n";
+}
+
 void GLSLProgramWriter::writeMainSourceCode(std::ostream& os, Program* program)
 {
     GpuProgramType gpuType = program->getType();
@@ -128,26 +148,45 @@ void GLSLProgramWriter::writeMainSourceCode(std::ostream& os, Program* program)
     }
 
     const UniformParameterList& parameterList = program->getParameters();
-    UniformParameterConstIterator itUniformParam = parameterList.begin();
     
     // Generate global variable code.
     writeUniformParametersTitle(os, program);
     os << std::endl;
 
-    // Write the uniforms 
-    for (itUniformParam = parameterList.begin();  itUniformParam != parameterList.end(); ++itUniformParam)
-    {
-        ParameterPtr pUniformParam = *itUniformParam;
+    auto* rs = Root::getSingleton().getRenderSystem();
+    auto hasSSO = rs ? rs->getCapabilities()->hasCapability(RSC_SEPARATE_SHADER_OBJECTS) : false;
 
-        os << "uniform\t"; 
-        os << mGpuConstTypeMap[pUniformParam->getType()];
-        os << "\t"; 
-        os << pUniformParam->getName();
-        if (pUniformParam->isArray() == true)
+    // Write the uniforms
+    UniformParameterList uniforms;
+    for (const auto& param : parameterList)
+    {
+        if(!param->isSampler())
         {
-            os << "[" << pUniformParam->getSize() << "]";   
+            uniforms.push_back(param);
+            continue;
         }
-        os << ";" << std::endl;     
+        writeSamplerParameter(os, param);
+        os << ";" << std::endl;
+    }
+    if (mIsVulkan && !uniforms.empty())
+    {
+        writeUniformBlock(os, "OgreUniforms", gpuType, uniforms);
+        uniforms.clear();
+    }
+
+    int uniformLoc = 0;
+    for (const auto& uparam : uniforms)
+    {
+        if(mGLSLVersion >= 430 && hasSSO)
+        {
+            os << "layout(location = " << uniformLoc << ") ";
+            auto esize = GpuConstantDefinition::getElementSize(uparam->getType(), true) / 4;
+            uniformLoc += esize * std::max<int>(uparam->getSize(), 1);
+        }
+
+        os << "uniform\t";
+        writeParameter(os, uparam);
+        os << ";\n";
     }
     os << std::endl;            
 
@@ -171,7 +210,7 @@ void GLSLProgramWriter::writeMainSourceCode(std::ostream& os, Program* program)
     for (; itParam != itParamEnd; ++itParam)
     {
         os << "\t";
-        writeLocalParameter(os, *itParam);
+        writeParameter(os, *itParam);
         os << ";" << std::endl;
     }
     os << std::endl;
@@ -235,6 +274,7 @@ void GLSLProgramWriter::writeProgramDependencies(std::ostream& os, Program* prog
     os << "//-----------------------------------------------------------------------------" << std::endl;
     os << "//                         PROGRAM DEPENDENCIES" << std::endl;
     os << "//-----------------------------------------------------------------------------" << std::endl;
+    os << "#define USE_OGRE_FROM_FUTURE" << std::endl;
     os << "#include <OgreUnifiedShader.h>" << std::endl;
 
     for (unsigned int i=0; i < program->getDependencyCount(); ++i)
@@ -250,9 +290,11 @@ void GLSLProgramWriter::writeInputParameters(std::ostream& os, Function* functio
     ShaderParameterConstIterator itParam = inParams.begin();
     ShaderParameterConstIterator itParamEnd = inParams.end();
 
+    int psInLocation = 0;
+
     for ( ; itParam != itParamEnd; ++itParam)
     {       
-        ParameterPtr pParam = *itParam;
+        const ParameterPtr& pParam = *itParam;
         Parameter::Content paramContent = pParam->getContent();
         const String& paramName = pParam->getName();
 
@@ -278,7 +320,7 @@ void GLSLProgramWriter::writeInputParameters(std::ostream& os, Function* functio
             os << mGpuConstTypeMap[pParam->getType()];
             os << "\t"; 
             os << paramName;
-            os << ", 0)" << std::endl; // location currently unused
+            os << ", " << psInLocation++ << ")\n";
         }
         else if (gpuType == GPT_VERTEX_PROGRAM && 
                  mContentToPerVertexAttributes.find(paramContent) != mContentToPerVertexAttributes.end())
@@ -305,21 +347,14 @@ void GLSLProgramWriter::writeInputParameters(std::ostream& os, Function* functio
             {
                 // the gl rendersystems only pass float attributes
                 GpuConstantType type = pParam->getType();
-                if(!GpuConstantDefinition::isFloat(type))
+                if(!mIsVulkan && !GpuConstantDefinition::isFloat(type))
                     type = GpuConstantType(type & ~GpuConstantDefinition::getBaseType(type));
                 os << mGpuConstTypeMap[type];
             }
             os << "\t"; 
-            os << mContentToPerVertexAttributes[paramContent];
-            os << ", 0)" << std::endl; // location currently unused
-        }
-        else if(paramContent == Parameter::SPC_COLOR_DIFFUSE && !mIsGLSLES)
-        {
-            pParam->_rename("gl_Color");
-        }
-        else if(paramContent == Parameter::SPC_COLOR_SPECULAR && !mIsGLSLES)
-        {
-            pParam->_rename("gl_SecondaryColor");
+            os << mContentToPerVertexAttributes[paramContent] << ", ";
+            writeParameterSemantic(os, pParam);  // maps to location
+            os << ")\n";
         }
         else
         {
@@ -340,9 +375,11 @@ void GLSLProgramWriter::writeOutParameters(std::ostream& os, Function* function,
     ShaderParameterConstIterator itParam = outParams.begin();
     ShaderParameterConstIterator itParamEnd = outParams.end();
 
+    int vsOutLocation = 0;
+
     for ( ; itParam != itParamEnd; ++itParam)
     {
-        ParameterPtr pParam = *itParam;
+        const ParameterPtr& pParam = *itParam;
 
         if(gpuType == GPT_VERTEX_PROGRAM)
         {
@@ -366,31 +403,21 @@ void GLSLProgramWriter::writeOutParameters(std::ostream& os, Function* function,
                 paramName[0] = 'i';
                 pParam->_rename(paramName);
 
-                os << mGpuConstTypeMap[pParam->getType()];
-                os << "\t";
-                os << paramName;
-                if (pParam->isArray() == true)
-                {
-                    os << "[" << pParam->getSize() << "]";  
-                }
-                os << ", 0)" << std::endl; // location currently unused
+                writeParameter(os, pParam);
+                os << ", " << vsOutLocation++ << ")\n";
             }
         }
         else if(gpuType == GPT_FRAGMENT_PROGRAM &&
                 pParam->getSemantic() == Parameter::SPS_COLOR)
         {                   
-            // GLSL fragment program has to write always gl_FragColor (but this is also deprecated after version 120)
-            // Always add gl_FragColor as an output.  The name is for compatibility.
-            if(mGLSLVersion <= 120 || (mIsGLSLES && mGLSLVersion == 100))
+            if(pParam->getIndex() == 0)
             {
+                // handled by UnifiedShader
                 pParam->_rename("gl_FragColor");
+                continue;
             }
-            else
-            {
-                if (mGLSLVersion >= 150)
-                    os << "layout(location = " << pParam->getIndex() << ") ";
-                os << "out vec4\t" << pParam->getName() << ";" << std::endl;
-            }
+
+            os << "OUT(vec4\t" << pParam->getName() << ", " << pParam->getIndex() << ")\n";
         }
     }
     
@@ -404,18 +431,6 @@ void GLSLProgramWriter::writeOutParameters(std::ostream& os, Function* function,
         }
     }
 }
-
-//-----------------------------------------------------------------------
-void GLSLProgramWriter::writeLocalParameter(std::ostream& os, ParameterPtr parameter)
-{
-    os << mGpuConstTypeMap[parameter->getType()];
-    os << "\t"; 
-    os << parameter->getName();     
-    if (parameter->isArray() == true)
-    {
-        os << "[" << parameter->getSize() << "]";   
-    }
-}
 //-----------------------------------------------------------------------
 }
 }
