@@ -35,6 +35,7 @@ THE SOFTWARE.
 #include "OgreConvexBody.h"
 #include "OgreHeaderPrefix.h"
 #include "OgreAxisAlignedBox.h"
+#include "OgreSceneNode.h"
 
 namespace Ogre {
 
@@ -45,19 +46,23 @@ namespace Ogre {
     *  @{
     */
     /** Implements the uniform shadow mapping algorithm in focused mode.
-    @remarks
+
         Differs from the default shadow mapping projection in that it focuses the
         shadow map on the visible areas of the scene. This results in better
         shadow map texel usage, at the expense of some 'swimming' of the shadow
         texture on receivers as the basis is constantly being reevaluated.
-    @note
+
         Original implementation by Matthias Fink <matthias.fink@web.de>, 2006.
     */
-    class _OgreExport FocusedShadowCameraSetup : public ShadowCameraSetup
+    class _OgreExport FocusedShadowCameraSetup : public DefaultShadowCameraSetup
     {
+        // Persistent calculations to prevent reallocation
+        mutable ConvexBody mBodyB;
+        /// Use tighter focus region?
+        bool mUseAggressiveRegion;
     protected:
         /** Transform to or from light space as defined by Wimmer et al.
-        @remarks
+
             Point and spot lights need to be converted to directional lights to enable a 1:1 
             light mapping. Otherwise a directional light may become a point light or a point 
             sink (opposite of a light source) or point/spot lights may become directional lights
@@ -66,19 +71,9 @@ namespace Ogre {
         static const Matrix4 msNormalToLightSpace;
         static const Matrix4 msLightSpaceToNormal;
 
-        /** Temporary preallocated frustum to set up a projection matrix in 
-            calculateShadowMappingMatrix().
-        */
-        std::unique_ptr<Frustum> mTempFrustum;
-
-        /** Temporary preallocated camera to set up a light frustum for clipping in FocusedShadowCameraSetup::calculateB.
-        */
-        std::unique_ptr<Camera> mLightFrustumCamera;
+        mutable const Camera* mLightFrustumCamera;
         mutable bool mLightFrustumCameraCalculated;
 
-        /// Use tighter focus region?
-        bool mUseAggressiveRegion;
-
         /** Internal class holding a point list representation of a convex body.
         */
         class _OgreExport PointListBody
@@ -96,13 +91,13 @@ namespace Ogre {
             void merge(const PointListBody& plb);
 
             /** Builds a point list body from a 'real' body.
-            @remarks
+
                 Inserts all vertices from a body into the point list with or without adding duplicate vertices.
             */
             void build(const ConvexBody& body, bool filterDuplicates = true);
 
             /** Builds a PointListBody from a Body and includes all the space in a given direction.
-            @remarks
+
                 Intersects the bounding box with a ray from each available point of the body with the given
                 direction. Base and intersection points are stored in a PointListBody structure.
             @note
@@ -140,37 +135,16 @@ namespace Ogre {
         };
 
         // Persistent calculations to prevent reallocation
-        mutable ConvexBody mBodyB;
         mutable PointListBody mPointListBodyB;
         mutable PointListBody mPointListBodyLVS;
 
     protected:
-        /** Calculates the standard shadow mapping matrix.
-        @remarks
-            Provides the view and projection matrix for standard shadow mapping.
-        @note
-            You can choose which things you want to have: view matrix and/or projection 
-            matrix and/or shadow camera. Passing a NULL value as parameter ignores the
-            generation of this specific value.
-        @param sm
-            Scene manager.
-        @param cam
-            Currently active camera.
-        @param light
-            Currently active light.
-        @param out_view
-            Calculated uniform view shadow mapping matrix (may be @c NULL).
-        @param out_proj
-            Calculated uniform projection shadow mapping matrix (may be @c NULL).
-        @param out_cam
-            Calculated uniform shadow camera (may be @c NULL).
-        */
-        void calculateShadowMappingMatrix(const SceneManager& sm, const Camera& cam, 
+        OGRE_DEPRECATED void calculateShadowMappingMatrix(const SceneManager& sm, const Camera& cam,
             const Light& light, Affine3 *out_view,
-            Matrix4 *out_proj, Camera *out_cam) const;
+            Matrix4 *out_proj, Frustum *out_cam) const;
 
         /** Calculates the intersection bodyB.
-        @remarks
+
             The intersection bodyB consists of the concatenation the cam frustum clipped 
             by the scene bounding box followed by a convex hullification with the light's 
             position and the clipping with the scene bounding box and the light frustum:
@@ -198,7 +172,7 @@ namespace Ogre {
             const AxisAlignedBox& sceneBB, const AxisAlignedBox& receiverBB, PointListBody *out_bodyB) const;
 
         /** Calculates the bodyLVS.
-        @remarks
+
             Calculates the bodyLVS which consists of the convex intersection operation 
             affecting the light frustum, the view frustum, and the current scene bounding
             box is used to find suitable positions in the viewer's frustum to build the 
@@ -219,7 +193,7 @@ namespace Ogre {
             const AxisAlignedBox& sceneBB, PointListBody *out_LVS) const;
 
         /** Returns the projection view direction.
-        @remarks
+
             After the matrix L_p is applied the orientation of the light space may tilt for
             non-identity projections. To prevent a false shadow cast the real view direction
             is evaluated and applied to the light matrix L.
@@ -234,7 +208,7 @@ namespace Ogre {
             const PointListBody& bodyLVS) const;
 
         /** Returns a valid near-point seen by the camera.
-        @remarks
+
             Returns a point that is situated near the camera by analyzing the bodyLVS that
             contains all the relevant scene space in front of the light and the camera in
             a point list array. The view matrix is relevant because the nearest point in
@@ -249,7 +223,7 @@ namespace Ogre {
 
         /** Transforms a given body to the unit cube (-1,-1,-1) / (+1,+1,+1) with a specific 
             shadow matrix enabled.
-        @remarks
+
             Transforms a given point list body object with the matrix m and then maps its
             extends to a (-1,-1,-1) / (+1,+1,+1) unit cube.
         @param m
@@ -259,13 +233,6 @@ namespace Ogre {
             are mapped to the unit cube.
         */
         Matrix4 transformToUnitCube(const Matrix4& m, const PointListBody& body) const;
-
-        /** Builds a view matrix.
-        @remarks
-            Builds a standard view matrix out of a given position, direction and up vector.
-        */
-        Affine3 buildViewMatrix(const Vector3& pos, const Vector3& dir, const Vector3& up) const;
-
     public:
         /// @deprecated use create()
         FocusedShadowCameraSetup(bool useAggressiveRegion = true);
