@@ -736,15 +736,7 @@ namespace Ogre {
                     // Use camera up
                     up = Vector3::UNIT_Z;
                 }
-                // cross twice to rederive, only direction is unaltered
-                Vector3 left = dir.crossProduct(up);
-                left.normalise();
-                up = dir.crossProduct(left);
-                up.normalise();
-                // Derive quaternion from axes
-                Quaternion q;
-                q.FromAxes(left, up, dir);
-                dummyNode.setOrientation(q);
+                dummyNode.setOrientation(Math::lookRotation(dir, up));
 
                 // The view matrix here already includes camera-relative changes if necessary
                 // since they are built into the frustum position
