@@ -4,62 +4,63 @@ This source file is part of OGRE
     (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2006 Torus Knot Software Ltd
-Also see acknowledgements in Readme.html
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
-This program is free software; you can redistribute it and/or modify it under
-the terms of the GNU Lesser General Public License as published by the Free Software
-Foundation; either version 2 of the License, or (at your option) any later
-version.
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
 
-This program is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
 
-You should have received a copy of the GNU Lesser General Public License along with
-this program; if not, write to the Free Software Foundation, Inc., 59 Temple
-Place - Suite 330, Boston, MA 02111-1307, USA, or go to
-http://www.gnu.org/copyleft/lesser.txt.
-
-You may alternatively use this source under the terms of a specific version of
-the OGRE Unrestricted License provided you have obtained such a license from
-Torus Knot Software Ltd.
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+THE SOFTWARE.
 -----------------------------------------------------------------------------
 */
 #include "OgreStableHeaders.h"
-#include "OgreHardwareBufferManager.h"
 #include "OgreVertexIndexData.h"
-#include "OgreLogManager.h"
-
 
 namespace Ogre {
 
     //-----------------------------------------------------------------------
-    template<> HardwareBufferManager* Singleton<HardwareBufferManager>::ms_Singleton = 0;
+    template<> HardwareBufferManager* Singleton<HardwareBufferManager>::msSingleton = 0;
     HardwareBufferManager* HardwareBufferManager::getSingletonPtr(void)
     {
-        return ms_Singleton;
+        return msSingleton;
     }
     HardwareBufferManager& HardwareBufferManager::getSingleton(void)
     {  
-        assert( ms_Singleton );  return ( *ms_Singleton );  
+        assert( msSingleton );  return ( *msSingleton );  
     }
-    // Free temporary vertex buffers every 5 minutes on 100fps
-    const size_t HardwareBufferManager::UNDER_USED_FRAME_THRESHOLD = 30000;
-    const size_t HardwareBufferManager::EXPIRED_DELAY_FRAME_THRESHOLD = 5;
-    //-----------------------------------------------------------------------
+    //---------------------------------------------------------------------
     HardwareBufferManager::HardwareBufferManager()
+    {
+    }
+    //---------------------------------------------------------------------
+    HardwareBufferManager::~HardwareBufferManager()
+    {
+    }
+    //---------------------------------------------------------------------
+    //---------------------------------------------------------------------
+    // Free temporary vertex buffers every 5 minutes on 100fps
+    const size_t HardwareBufferManagerBase::UNDER_USED_FRAME_THRESHOLD = 30000;
+    const size_t HardwareBufferManagerBase::EXPIRED_DELAY_FRAME_THRESHOLD = 5;
+    //-----------------------------------------------------------------------
+    HardwareBufferManagerBase::HardwareBufferManagerBase()
         : mUnderUsedFrameCount(0)
     {
     }
     //-----------------------------------------------------------------------
-    HardwareBufferManager::~HardwareBufferManager()
+    HardwareBufferManagerBase::~HardwareBufferManagerBase()
     {
-        // Clear vertex/index buffer list first, avoid destroyed notify do
-        // unnecessary work, and we'll destroy everything here.
-		mVertexBuffers.clear();
-		mIndexBuffers.clear();
-
         // Destroy everything
         destroyAllDeclarations();
         destroyAllBindings();
@@ -68,59 +69,62 @@ namespace Ogre {
         // No need to destroy temp buffers - they will be destroyed automatically.
     }
     //-----------------------------------------------------------------------
-    VertexDeclaration* HardwareBufferManager::createVertexDeclaration(void)
+    VertexDeclaration* HardwareBufferManagerBase::createVertexDeclaration(void)
     {
         VertexDeclaration* decl = createVertexDeclarationImpl();
-		OGRE_LOCK_MUTEX(mVertexDeclarationsMutex)
+        OGRE_LOCK_MUTEX(mVertexDeclarationsMutex);
         mVertexDeclarations.insert(decl);
         return decl;
     }
     //-----------------------------------------------------------------------
-    void HardwareBufferManager::destroyVertexDeclaration(VertexDeclaration* decl)
+    void HardwareBufferManagerBase::destroyVertexDeclaration(VertexDeclaration* decl)
     {
-		OGRE_LOCK_MUTEX(mVertexDeclarationsMutex)
+        OGRE_LOCK_MUTEX(mVertexDeclarationsMutex);
+        OgreAssertDbg(mVertexDeclarations.find(decl) != mVertexDeclarations.end(), "unknown decl");
         mVertexDeclarations.erase(decl);
         destroyVertexDeclarationImpl(decl);
     }
     //-----------------------------------------------------------------------
-	VertexBufferBinding* HardwareBufferManager::createVertexBufferBinding(void)
-	{
-		VertexBufferBinding* ret = createVertexBufferBindingImpl();
-		OGRE_LOCK_MUTEX(mVertexBufferBindingsMutex)
-		mVertexBufferBindings.insert(ret);
-		return ret;
-	}
-    //-----------------------------------------------------------------------
-	void HardwareBufferManager::destroyVertexBufferBinding(VertexBufferBinding* binding)
-	{
-		OGRE_LOCK_MUTEX(mVertexBufferBindingsMutex)
-		mVertexBufferBindings.erase(binding);
-		destroyVertexBufferBindingImpl(binding);
-	}
-    //-----------------------------------------------------------------------
-    VertexDeclaration* HardwareBufferManager::createVertexDeclarationImpl(void)
+    VertexBufferBinding* HardwareBufferManagerBase::createVertexBufferBinding(void)
     {
-        return new VertexDeclaration();
+        VertexBufferBinding* ret = createVertexBufferBindingImpl();
+        OGRE_LOCK_MUTEX(mVertexBufferBindingsMutex);
+        mVertexBufferBindings.insert(ret);
+        return ret;
     }
     //-----------------------------------------------------------------------
-    void HardwareBufferManager::destroyVertexDeclarationImpl(VertexDeclaration* decl)
+    void HardwareBufferManagerBase::destroyVertexBufferBinding(VertexBufferBinding* binding)
     {
-        delete decl;
+        OGRE_LOCK_MUTEX(mVertexBufferBindingsMutex);
+        OgreAssertDbg(mVertexBufferBindings.find(binding) != mVertexBufferBindings.end(),
+                      "unknown binding");
+        mVertexBufferBindings.erase(binding);
+        destroyVertexBufferBindingImpl(binding);
     }
     //-----------------------------------------------------------------------
-	VertexBufferBinding* HardwareBufferManager::createVertexBufferBindingImpl(void)
-	{
-		return new VertexBufferBinding();
-	}
-    //-----------------------------------------------------------------------
-	void HardwareBufferManager::destroyVertexBufferBindingImpl(VertexBufferBinding* binding)
-	{
-		delete binding;
-	}
-    //-----------------------------------------------------------------------
-    void HardwareBufferManager::destroyAllDeclarations(void)
+    VertexDeclaration* HardwareBufferManagerBase::createVertexDeclarationImpl(void)
     {
-		OGRE_LOCK_MUTEX(mVertexDeclarationsMutex)
+        return OGRE_NEW VertexDeclaration();
+    }
+    //-----------------------------------------------------------------------
+    void HardwareBufferManagerBase::destroyVertexDeclarationImpl(VertexDeclaration* decl)
+    {
+        OGRE_DELETE decl;
+    }
+    //-----------------------------------------------------------------------
+    VertexBufferBinding* HardwareBufferManagerBase::createVertexBufferBindingImpl(void)
+    {
+        return OGRE_NEW VertexBufferBinding();
+    }
+    //-----------------------------------------------------------------------
+    void HardwareBufferManagerBase::destroyVertexBufferBindingImpl(VertexBufferBinding* binding)
+    {
+        OGRE_DELETE binding;
+    }
+    //-----------------------------------------------------------------------
+    void HardwareBufferManagerBase::destroyAllDeclarations(void)
+    {
+        OGRE_LOCK_MUTEX(mVertexDeclarationsMutex);
         VertexDeclarationList::iterator decl;
         for (decl = mVertexDeclarations.begin(); decl != mVertexDeclarations.end(); ++decl)
         {
@@ -129,9 +133,9 @@ namespace Ogre {
         mVertexDeclarations.clear();
     }
     //-----------------------------------------------------------------------
-    void HardwareBufferManager::destroyAllBindings(void)
+    void HardwareBufferManagerBase::destroyAllBindings(void)
     {
-		OGRE_LOCK_MUTEX(mVertexBufferBindingsMutex)
+        OGRE_LOCK_MUTEX(mVertexBufferBindingsMutex);
         VertexBufferBindingList::iterator bind;
         for (bind = mVertexBufferBindings.begin(); bind != mVertexBufferBindings.end(); ++bind)
         {
@@ -139,72 +143,70 @@ namespace Ogre {
         }
         mVertexBufferBindings.clear();
     }
-	//-----------------------------------------------------------------------
-    void HardwareBufferManager::registerVertexBufferSourceAndCopy(
-			const HardwareVertexBufferSharedPtr& sourceBuffer,
-			const HardwareVertexBufferSharedPtr& copy)
-	{
-		OGRE_LOCK_MUTEX(mTempBuffersMutex)
-		// Add copy to free temporary vertex buffers
-        mFreeTempVertexBufferMap.insert(
-            FreeTemporaryVertexBufferMap::value_type(sourceBuffer.get(), copy));
-	}
-	//-----------------------------------------------------------------------
+    //-----------------------------------------------------------------------
+    void HardwareBufferManagerBase::registerVertexBufferSourceAndCopy(
+            const HardwareVertexBufferSharedPtr& sourceBuffer,
+            const HardwareVertexBufferSharedPtr& copy)
+    {
+            OGRE_LOCK_MUTEX(mTempBuffersMutex);
+        // Add copy to free temporary vertex buffers
+        mFreeTempVertexBufferMap.emplace(sourceBuffer.get(), copy);
+    }
+    //-----------------------------------------------------------------------
     HardwareVertexBufferSharedPtr 
-    HardwareBufferManager::allocateVertexBufferCopy(
+    HardwareBufferManagerBase::allocateVertexBufferCopy(
         const HardwareVertexBufferSharedPtr& sourceBuffer, 
         BufferLicenseType licenseType, HardwareBufferLicensee* licensee,
         bool copyData)
     {
-		// pre-lock the mVertexBuffers mutex, which would usually get locked in
-		//  makeBufferCopy / createVertexBuffer
-		// this prevents a deadlock in _notifyVertexBufferDestroyed
-		// which locks the same mutexes (via other methods) but in reverse order
-		OGRE_LOCK_MUTEX(mVertexBuffersMutex)
-		{
-			OGRE_LOCK_MUTEX(mTempBuffersMutex)
-			HardwareVertexBufferSharedPtr vbuf;
+        // pre-lock the mVertexBuffers mutex, which would usually get locked in
+        //  makeBufferCopy / createVertexBuffer
+        // this prevents a deadlock in _notifyVertexBufferDestroyed
+        // which locks the same mutexes (via other methods) but in reverse order
+        OGRE_LOCK_MUTEX(mVertexBuffersMutex);
+        {
+                    OGRE_LOCK_MUTEX(mTempBuffersMutex);
+            HardwareVertexBufferSharedPtr vbuf;
 
-			// Locate existing buffer copy in temporary vertex buffers
-			FreeTemporaryVertexBufferMap::iterator i = 
-				mFreeTempVertexBufferMap.find(sourceBuffer.get());
-			if (i == mFreeTempVertexBufferMap.end())
-			{
-				// copy buffer, use shadow buffer and make dynamic
-				vbuf = makeBufferCopy(
-					sourceBuffer, 
-					HardwareBuffer::HBU_DYNAMIC_WRITE_ONLY_DISCARDABLE, 
-					true);
-			}
-			else
-			{
-				// Allocate existing copy
-				vbuf = i->second;
-				mFreeTempVertexBufferMap.erase(i);
-			}
+            // Locate existing buffer copy in temporary vertex buffers
+            FreeTemporaryVertexBufferMap::iterator i = 
+                mFreeTempVertexBufferMap.find(sourceBuffer.get());
+            if (i == mFreeTempVertexBufferMap.end())
+            {
+                // copy buffer, use shadow buffer and make dynamic
+                vbuf = makeBufferCopy(
+                    sourceBuffer, 
+                    HardwareBuffer::HBU_DYNAMIC_WRITE_ONLY_DISCARDABLE, 
+                    true);
+            }
+            else
+            {
+                // Allocate existing copy
+                vbuf = i->second;
+                mFreeTempVertexBufferMap.erase(i);
+            }
 
-			// Copy data?
-			if (copyData)
-			{
-				vbuf->copyData(*(sourceBuffer.get()), 0, 0, sourceBuffer->getSizeInBytes(), true);
-			}
+            // Copy data?
+            if (copyData)
+            {
+                vbuf->copyData(*(sourceBuffer.get()), 0, 0, sourceBuffer->getSizeInBytes(), true);
+            }
 
-			// Insert copy into licensee list
-			mTempVertexBufferLicenses.insert(
-				TemporaryVertexBufferLicenseMap::value_type(
-					vbuf.get(),
-					VertexBufferLicense(sourceBuffer.get(), licenseType, EXPIRED_DELAY_FRAME_THRESHOLD, vbuf, licensee)));
-			return vbuf;
-		}
+            // Insert copy into licensee list
+            mTempVertexBufferLicenses.emplace(
+                    vbuf.get(),
+                    VertexBufferLicense(sourceBuffer.get(), licenseType, EXPIRED_DELAY_FRAME_THRESHOLD, vbuf, licensee));
+            return vbuf;
+        }
 
     }
     //-----------------------------------------------------------------------
-    void HardwareBufferManager::releaseVertexBufferCopy(
+    void HardwareBufferManagerBase::releaseVertexBufferCopy(
         const HardwareVertexBufferSharedPtr& bufferCopy)
     {
-		OGRE_LOCK_MUTEX(mTempBuffersMutex)
+        OGRE_LOCK_MUTEX(mTempBuffersMutex);
 
-		TemporaryVertexBufferLicenseMap::iterator i =
+        TemporaryVertexBufferLicenseMap::iterator i =
             mTempVertexBufferLicenses.find(bufferCopy.get());
         if (i != mTempVertexBufferLicenses.end())
         {
@@ -212,16 +214,15 @@ namespace Ogre {
 
             vbl.licensee->licenseExpired(vbl.buffer.get());
 
-            mFreeTempVertexBufferMap.insert(
-                FreeTemporaryVertexBufferMap::value_type(vbl.originalBufferPtr, vbl.buffer));
+            mFreeTempVertexBufferMap.emplace(vbl.originalBufferPtr, vbl.buffer);
             mTempVertexBufferLicenses.erase(i);
         }
     }
     //-----------------------------------------------------------------------
-    void HardwareBufferManager::touchVertexBufferCopy(
+    void HardwareBufferManagerBase::touchVertexBufferCopy(
             const HardwareVertexBufferSharedPtr& bufferCopy)
     {
-		OGRE_LOCK_MUTEX(mTempBuffersMutex)
+        OGRE_LOCK_MUTEX(mTempBuffersMutex);
         TemporaryVertexBufferLicenseMap::iterator i =
             mTempVertexBufferLicenses.find(bufferCopy.get());
         if (i != mTempVertexBufferLicenses.end())
@@ -233,9 +234,9 @@ namespace Ogre {
         }
     }
     //-----------------------------------------------------------------------
-    void HardwareBufferManager::_freeUnusedBufferCopies(void)
+    void HardwareBufferManagerBase::_freeUnusedBufferCopies(void)
     {
-		OGRE_LOCK_MUTEX(mTempBuffersMutex)
+        OGRE_LOCK_MUTEX(mTempBuffersMutex);
         size_t numFreed = 0;
 
         // Free unused temporary buffers
@@ -247,14 +248,14 @@ namespace Ogre {
             // Free the temporary buffer that referenced by ourself only.
             // TODO: Some temporary buffers are bound to vertex buffer bindings
             // but not checked out, need to sort out method to unbind them.
-            if (icur->second.useCount() <= 1)
+            if (icur->second.use_count() <= 1)
             {
                 ++numFreed;
                 mFreeTempVertexBufferMap.erase(icur);
             }
         }
 
-        StringUtil::StrStreamType str;
+        StringStream str;
         if (numFreed)
         {
             str << "HardwareBufferManager: Freed " << numFreed << " unused temporary vertex buffers.";
@@ -266,9 +267,9 @@ namespace Ogre {
         LogManager::getSingleton().logMessage(str.str(), LML_TRIVIAL);
     }
     //-----------------------------------------------------------------------
-    void HardwareBufferManager::_releaseBufferCopies(bool forceFreeUnused)
+    void HardwareBufferManagerBase::_releaseBufferCopies(bool forceFreeUnused)
     {
-		OGRE_LOCK_MUTEX(mTempBuffersMutex)
+        OGRE_LOCK_MUTEX(mTempBuffersMutex);
         size_t numUnused = mFreeTempVertexBufferMap.size();
         size_t numUsed = mTempVertexBufferLicenses.size();
 
@@ -282,10 +283,9 @@ namespace Ogre {
             if (vbl.licenseType == BLT_AUTOMATIC_RELEASE &&
                 (forceFreeUnused || --vbl.expiredDelay <= 0))
             {
-				vbl.licensee->licenseExpired(vbl.buffer.get());
+                vbl.licensee->licenseExpired(vbl.buffer.get());
 
-                mFreeTempVertexBufferMap.insert(
-                    FreeTemporaryVertexBufferMap::value_type(vbl.originalBufferPtr, vbl.buffer));
+                mFreeTempVertexBufferMap.emplace(vbl.originalBufferPtr, vbl.buffer);
                 mTempVertexBufferLicenses.erase(icur);
             }
         }
@@ -317,16 +317,16 @@ namespace Ogre {
         }
     }
     //-----------------------------------------------------------------------
-    void HardwareBufferManager::_forceReleaseBufferCopies(
+    void HardwareBufferManagerBase::_forceReleaseBufferCopies(
         const HardwareVertexBufferSharedPtr& sourceBuffer)
     {
         _forceReleaseBufferCopies(sourceBuffer.get());
     }
     //-----------------------------------------------------------------------
-    void HardwareBufferManager::_forceReleaseBufferCopies(
+    void HardwareBufferManagerBase::_forceReleaseBufferCopies(
         HardwareVertexBuffer* sourceBuffer)
     {
-		OGRE_LOCK_MUTEX(mTempBuffersMutex)
+        OGRE_LOCK_MUTEX(mTempBuffersMutex);
         // Erase the copies which are licensed out
         TemporaryVertexBufferLicenseMap::iterator i;
         i = mTempVertexBufferLicenses.begin();
@@ -365,7 +365,7 @@ namespace Ogre {
             std::list<HardwareVertexBufferSharedPtr> holdForDelayDestroy;
             for (_Iter it = range.first; it != range.second; ++it)
             {
-                if (it->second.useCount() <= 1)
+                if (it->second.use_count() <= 1)
                 {
                     holdForDelayDestroy.push_back(it->second);
                 }
@@ -376,33 +376,32 @@ namespace Ogre {
             // holdForDelayDestroy will destroy auto.
         }
     }
-	//-----------------------------------------------------------------------
-	void HardwareBufferManager::_notifyVertexBufferDestroyed(HardwareVertexBuffer* buf)
-	{
-		OGRE_LOCK_MUTEX(mVertexBuffersMutex)
+    //-----------------------------------------------------------------------
+    void HardwareBufferManagerBase::_notifyVertexBufferDestroyed(HardwareVertexBuffer* buf)
+    {
+            OGRE_LOCK_MUTEX(mVertexBuffersMutex);
 
-		VertexBufferList::iterator i = mVertexBuffers.find(buf);
-		if (i != mVertexBuffers.end())
-		{
+        VertexBufferList::iterator i = mVertexBuffers.find(buf);
+        if (i != mVertexBuffers.end())
+        {
             // release vertex buffer copies
-			mVertexBuffers.erase(i);
+            mVertexBuffers.erase(i);
             _forceReleaseBufferCopies(buf);
-		}
-	}
-	//-----------------------------------------------------------------------
-	void HardwareBufferManager::_notifyIndexBufferDestroyed(HardwareIndexBuffer* buf)
-	{
-		OGRE_LOCK_MUTEX(mIndexBuffersMutex)
-
-		IndexBufferList::iterator i = mIndexBuffers.find(buf);
-		if (i != mIndexBuffers.end())
-		{
-			mIndexBuffers.erase(i);
-		}
-	}
+        }
+    }
+    RenderToVertexBufferSharedPtr HardwareBufferManagerBase::createRenderToVertexBuffer()
+    {
+        OGRE_EXCEPT(Exception::ERR_RENDERINGAPI_ERROR, "not supported by RenderSystem");
+    }
+    HardwareBufferPtr HardwareBufferManagerBase::createUniformBuffer(size_t sizeBytes,
+                                                                     HardwareBufferUsage usage,
+                                                                     bool useShadowBuffer)
+    {
+        OGRE_EXCEPT(Exception::ERR_RENDERINGAPI_ERROR, "not supported by RenderSystem");
+    }
     //-----------------------------------------------------------------------
     HardwareVertexBufferSharedPtr 
-    HardwareBufferManager::makeBufferCopy(
+    HardwareBufferManagerBase::makeBufferCopy(
         const HardwareVertexBufferSharedPtr& source,
         HardwareBuffer::Usage usage, bool useShadowBuffer)
     {
@@ -417,27 +416,25 @@ namespace Ogre {
     TempBlendedBufferInfo::~TempBlendedBufferInfo(void)
     {
         // check that temp buffers have been released
-        HardwareBufferManager &mgr = HardwareBufferManager::getSingleton();
-        if (!destPositionBuffer.isNull())
-            mgr.releaseVertexBufferCopy(destPositionBuffer);
-        if (!destNormalBuffer.isNull())
-            mgr.releaseVertexBufferCopy(destNormalBuffer);
+        if (destPositionBuffer)
+            destPositionBuffer->getManager()->releaseVertexBufferCopy(destPositionBuffer);
+        if (destNormalBuffer)
+            destNormalBuffer->getManager()->releaseVertexBufferCopy(destNormalBuffer);
 
     }
     //-----------------------------------------------------------------------------
     void TempBlendedBufferInfo::extractFrom(const VertexData* sourceData)
     {
         // Release old buffer copies first
-        HardwareBufferManager &mgr = HardwareBufferManager::getSingleton();
-        if (!destPositionBuffer.isNull())
+        if (destPositionBuffer)
         {
-            mgr.releaseVertexBufferCopy(destPositionBuffer);
-            assert(destPositionBuffer.isNull());
+            destPositionBuffer->getManager()->releaseVertexBufferCopy(destPositionBuffer);
+            assert(!destPositionBuffer);
         }
-        if (!destNormalBuffer.isNull())
+        if (destNormalBuffer)
         {
-            mgr.releaseVertexBufferCopy(destNormalBuffer);
-            assert(destNormalBuffer.isNull());
+            destNormalBuffer->getManager()->releaseVertexBufferCopy(destNormalBuffer);
+            assert(!destNormalBuffer);
         }
 
         VertexDeclaration* decl = sourceData->vertexDeclaration;
@@ -449,11 +446,12 @@ namespace Ogre {
 
         posBindIndex = posElem->getSource();
         srcPositionBuffer = bind->getBuffer(posBindIndex);
+        srcNormalBuffer.reset();
 
         if (!normElem)
         {
             posNormalShareBuffer = false;
-            srcNormalBuffer.setNull();
+            posNormalExtraData = posElem->getSize() != srcPositionBuffer->getVertexSize();
         }
         else
         {
@@ -461,10 +459,11 @@ namespace Ogre {
             if (normBindIndex == posBindIndex)
             {
                 posNormalShareBuffer = true;
-                srcNormalBuffer.setNull();
+                posNormalExtraData = (posElem->getSize() + normElem->getSize()) != srcPositionBuffer->getVertexSize();
             }
             else
             {
+                posNormalExtraData = false;
                 posNormalShareBuffer = false;
                 srcNormalBuffer = bind->getBuffer(normBindIndex);
             }
@@ -476,49 +475,45 @@ namespace Ogre {
         bindPositions = positions;
         bindNormals = normals;
 
-        HardwareBufferManager &mgr = HardwareBufferManager::getSingleton();
-
-        if (positions && destPositionBuffer.isNull())
+        if (positions && !destPositionBuffer)
         {
-            destPositionBuffer = mgr.allocateVertexBufferCopy(srcPositionBuffer, 
-                HardwareBufferManager::BLT_AUTOMATIC_RELEASE, this);
+            destPositionBuffer = srcPositionBuffer->getManager()->allocateVertexBufferCopy(srcPositionBuffer, 
+                HardwareBufferManagerBase::BLT_AUTOMATIC_RELEASE, this, posNormalExtraData);
         }
-        if (normals && !posNormalShareBuffer && !srcNormalBuffer.isNull() && destNormalBuffer.isNull())
+        if (normals && !posNormalShareBuffer && srcNormalBuffer && !destNormalBuffer)
         {
-            destNormalBuffer = mgr.allocateVertexBufferCopy(srcNormalBuffer, 
-                HardwareBufferManager::BLT_AUTOMATIC_RELEASE, this);
+            destNormalBuffer = srcNormalBuffer->getManager()->allocateVertexBufferCopy(srcNormalBuffer, 
+                HardwareBufferManagerBase::BLT_AUTOMATIC_RELEASE, this);
         }
     }
-	//-----------------------------------------------------------------------------
-	bool TempBlendedBufferInfo::buffersCheckedOut(bool positions, bool normals) const
-	{
-        HardwareBufferManager &mgr = HardwareBufferManager::getSingleton();
-
+    //-----------------------------------------------------------------------------
+    bool TempBlendedBufferInfo::buffersCheckedOut(bool positions, bool normals) const
+    {
         if (positions || (normals && posNormalShareBuffer))
         {
-            if (destPositionBuffer.isNull())
+            if (!destPositionBuffer)
                 return false;
 
-            mgr.touchVertexBufferCopy(destPositionBuffer);
+            destPositionBuffer->getManager()->touchVertexBufferCopy(destPositionBuffer);
         }
 
         if (normals && !posNormalShareBuffer)
         {
-            if (destNormalBuffer.isNull())
+            if (!destNormalBuffer)
                 return false;
 
-            mgr.touchVertexBufferCopy(destNormalBuffer);
+            destNormalBuffer->getManager()->touchVertexBufferCopy(destNormalBuffer);
         }
 
-		return true;
-	}
+        return true;
+    }
     //-----------------------------------------------------------------------------
     void TempBlendedBufferInfo::bindTempCopies(VertexData* targetData, bool suppressHardwareUpload)
     {
         this->destPositionBuffer->suppressHardwareUpdate(suppressHardwareUpload);
         targetData->vertexBufferBinding->setBinding(
             this->posBindIndex, this->destPositionBuffer);
-        if (bindNormals && !posNormalShareBuffer && !destNormalBuffer.isNull())
+        if (bindNormals && !posNormalShareBuffer && destNormalBuffer)
         {
             this->destNormalBuffer->suppressHardwareUpdate(suppressHardwareUpload);
             targetData->vertexBufferBinding->setBinding(
@@ -532,9 +527,9 @@ namespace Ogre {
             || buffer == destNormalBuffer.get());
 
         if (buffer == destPositionBuffer.get())
-            destPositionBuffer.setNull();
+            destPositionBuffer.reset();
         if (buffer == destNormalBuffer.get())
-            destNormalBuffer.setNull();
+            destNormalBuffer.reset();
 
     }
 
