@@ -682,10 +682,8 @@ namespace Ogre {
     unsigned short VertexDeclaration::getNextFreeTextureCoordinate() const
     {
         unsigned short texCoord = 0;
-        for (VertexElementList::const_iterator i = mElementList.begin(); 
-             i != mElementList.end(); ++i)
+        for (const auto & el : mElementList)
         {
-            const VertexElement& el = *i;
             if (el.getSemantic() == VES_TEXTURE_COORDINATES)
             {
                 ++texCoord;
