@@ -273,7 +273,7 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     Node* Node::createChild(const String& name, const Vector3& inTranslate, const Quaternion& inRotate)
     {
-        OgreAssert(!name.empty(), "name must not be empty");
+        OgreAssert(!name.empty(), "");
         Node* newNode = createChildImpl(name);
         newNode->setPosition(inTranslate);
         newNode->setOrientation(inRotate);
@@ -309,28 +309,19 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     Node* Node::removeChild(unsigned short index)
     {
-        if (index < mChildren.size())
-        {
-            ChildNodeMap::iterator i = mChildren.begin();
-            i += index;
-            Node* ret = *i;
+        OgreAssert(index < mChildren.size(), "");
 
-            // cancel any pending update
-            cancelUpdate(ret);
+        ChildNodeMap::iterator i = mChildren.begin();
+        i += index;
+        Node* ret = *i;
 
-            std::swap(*i, mChildren.back());
-            mChildren.pop_back();
-            ret->setParent(NULL);
-            return ret;
-        }
-        else
-        {
-            OGRE_EXCEPT(
-                Exception::ERR_INVALIDPARAMS,
-                "Child index out of bounds.",
-                "Node::getChild" );
-        }
-        return 0;
+        // cancel any pending update
+        cancelUpdate(ret);
+
+        std::swap(*i, mChildren.back());
+        mChildren.pop_back();
+        ret->setParent(NULL);
+        return ret;
     }
     //-----------------------------------------------------------------------
     Node* Node::removeChild(Node* child)
@@ -379,28 +370,12 @@ namespace Ogre {
         needUpdate();
     }
 
-
-    //-----------------------------------------------------------------------
-    void Node::setPosition(Real x, Real y, Real z)
-    {
-        Vector3 v(x,y,z);
-        setPosition(v);
-    }
-
     //-----------------------------------------------------------------------
     Matrix3 Node::getLocalAxes(void) const
     {
-        Vector3 axisX = Vector3::UNIT_X;
-        Vector3 axisY = Vector3::UNIT_Y;
-        Vector3 axisZ = Vector3::UNIT_Z;
-
-        axisX = mOrientation * axisX;
-        axisY = mOrientation * axisY;
-        axisZ = mOrientation * axisZ;
-
-        return Matrix3(axisX.x, axisY.x, axisZ.x,
-                       axisX.y, axisY.y, axisZ.y,
-                       axisX.z, axisY.z, axisZ.z);
+        Matrix3 ret;
+        mOrientation.ToRotationMatrix(ret);
+        return ret;
     }
 
     //-----------------------------------------------------------------------
@@ -430,48 +405,6 @@ namespace Ogre {
         needUpdate();
 
     }
-    //-----------------------------------------------------------------------
-    void Node::translate(Real x, Real y, Real z, TransformSpace relativeTo)
-    {
-        Vector3 v(x,y,z);
-        translate(v, relativeTo);
-    }
-    //-----------------------------------------------------------------------
-    void Node::translate(const Matrix3& axes, const Vector3& move, TransformSpace relativeTo)
-    {
-        Vector3 derived = axes * move;
-        translate(derived, relativeTo);
-    }
-    //-----------------------------------------------------------------------
-    void Node::translate(const Matrix3& axes, Real x, Real y, Real z, TransformSpace relativeTo)
-    {
-        Vector3 d(x,y,z);
-        translate(axes,d,relativeTo);
-    }
-    //-----------------------------------------------------------------------
-    void Node::roll(const Radian& angle, TransformSpace relativeTo)
-    {
-        rotate(Vector3::UNIT_Z, angle, relativeTo);
-    }
-    //-----------------------------------------------------------------------
-    void Node::pitch(const Radian& angle, TransformSpace relativeTo)
-    {
-        rotate(Vector3::UNIT_X, angle, relativeTo);
-    }
-    //-----------------------------------------------------------------------
-    void Node::yaw(const Radian& angle, TransformSpace relativeTo)
-    {
-        rotate(Vector3::UNIT_Y, angle, relativeTo);
-
-    }
-    //-----------------------------------------------------------------------
-    void Node::rotate(const Vector3& axis, const Radian& angle, TransformSpace relativeTo)
-    {
-        Quaternion q;
-        q.FromAngleAxis(angle,axis);
-        rotate(q, relativeTo);
-    }
-
     //-----------------------------------------------------------------------
     void Node::rotate(const Quaternion& q, TransformSpace relativeTo)
     {
@@ -627,12 +560,6 @@ namespace Ogre {
         mScale = inScale;
         needUpdate();
     }
-    //-----------------------------------------------------------------------
-    void Node::setScale(Real x, Real y, Real z)
-    {
-        setScale(Vector3(x, y, z));
-    }
-
     //-----------------------------------------------------------------------
     void Node::setInheritOrientation(bool inherit)
     {
@@ -700,7 +627,7 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     Node* Node::removeChild(const String& name)
     {
-        OgreAssert(!name.empty(), "name must not be empty");
+        OgreAssert(!name.empty(), "");
         NodeNameExists pred = {name};
         ChildNodeMap::iterator i = std::find_if(mChildren.begin(), mChildren.end(), pred);
 
@@ -736,9 +663,10 @@ namespace Ogre {
     Real Node::getSquaredViewDepth(const Camera* cam) const
     {
         Vector3 diff = _getDerivedPosition() - cam->getDerivedPosition();
+        Vector3 zAxis = cam->getDerivedDirection();
 
-        // NB use squared length rather than real depth to avoid square root
-        return diff.squaredLength();
+        // NB use squared length to avoid square root
+        return cam->getSortMode() == SM_DISTANCE ? diff.squaredLength() : Math::Sqr(zAxis.dotProduct(diff));
     }
     //-----------------------------------------------------------------------
     void Node::needUpdate(bool forceParentUpdate)
@@ -801,92 +729,14 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     void Node::processQueuedUpdates(void)
     {
-        for (QueuedUpdates::iterator i = msQueuedUpdates.begin();
-            i != msQueuedUpdates.end(); ++i)
+        for (auto n : msQueuedUpdates)
         {
             // Update, and force parent update since chances are we've ended
             // up with some mixed state in there due to re-entrancy
-            Node* n = *i;
             n->mQueuedForUpdate = false;
             n->needUpdate(true);
         }
         msQueuedUpdates.clear();
     }
-    //---------------------------------------------------------------------
-    Node::DebugRenderable* Node::getDebugRenderable(Real scaling)
-    {
-        if (!mDebug)
-        {
-            mDebug.reset(new DebugRenderable(this));
-        }
-        mDebug->setScaling(scaling);
-        return mDebug.get();
-    }
-    //---------------------------------------------------------------------
-    //-----------------------------------------------------------------------
-    Node::DebugRenderable::DebugRenderable(Node* parent)
-        : mParent(parent)
-    {
-        String matName = "Ogre/Debug/AxesMat";
-        mMat = MaterialManager::getSingleton().getByName(matName, ResourceGroupManager::INTERNAL_RESOURCE_GROUP_NAME);
-        if (!mMat)
-        {
-            mMat = MaterialManager::getSingleton().create(matName, ResourceGroupManager::INTERNAL_RESOURCE_GROUP_NAME);
-            Pass* p = mMat->getTechnique(0)->getPass(0);
-            p->setLightingEnabled(false);
-            p->setPolygonModeOverrideable(false);
-            p->setVertexColourTracking(TVC_AMBIENT);
-            p->setSceneBlending(SBT_TRANSPARENT_ALPHA);
-            p->setCullingMode(CULL_NONE);
-            p->setDepthWriteEnabled(false);
-            p->setDepthCheckEnabled(false);
-        }
-
-        String meshName = "Ogre/Debug/AxesMesh";
-        mMeshPtr = MeshManager::getSingleton().getByName(meshName, ResourceGroupManager::INTERNAL_RESOURCE_GROUP_NAME);
-        if (!mMeshPtr->isLoaded())
-        {
-            mMeshPtr->load();
-            mMeshPtr->getSubMeshes()[0]->setMaterial(mMat);
-        }
-
-    }
-    //---------------------------------------------------------------------
-    Node::DebugRenderable::~DebugRenderable()
-    {
-    }
-    //-----------------------------------------------------------------------
-    const MaterialPtr& Node::DebugRenderable::getMaterial(void) const
-    {
-        return mMat;
-    }
-    //---------------------------------------------------------------------
-    void Node::DebugRenderable::getRenderOperation(RenderOperation& op)
-    {
-        return mMeshPtr->getSubMesh(0)->_getRenderOperation(op);
-    }
-    //-----------------------------------------------------------------------
-    void Node::DebugRenderable::getWorldTransforms(Matrix4* xform) const
-    {
-        // Assumes up to date
-        *xform = mParent->_getFullTransform();
-        if (!Math::RealEqual(mScaling, 1.0))
-        {
-            *xform = (*xform) * Affine3::getScale(mScaling, mScaling, mScaling);
-        }
-    }
-    //-----------------------------------------------------------------------
-    Real Node::DebugRenderable::getSquaredViewDepth(const Camera* cam) const
-    {
-        return mParent->getSquaredViewDepth(cam);
-    }
-    //-----------------------------------------------------------------------
-    const LightList& Node::DebugRenderable::getLights(void) const
-    {
-        // Nodes should not be lit by the scene, this will not get called
-        static LightList ll;
-        return ll;
-    }
-
 }
 
