@@ -49,9 +49,9 @@ namespace Ogre {
     {
         // Detach all objects, do this manually to avoid needUpdate() call 
         // which can fail because of deleted items
-        for (ObjectMap::iterator itr = mObjectsByName.begin(); itr != mObjectsByName.end(); ++itr )
+        for (auto & itr : mObjectsByName)
         {
-            (*itr)->_notifyAttached((SceneNode*)0);
+            itr->_notifyAttached((SceneNode*)0);
         }
         mObjectsByName.clear();
     }
@@ -193,9 +193,9 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     void SceneNode::detachAllObjects(void)
     {
-        for (ObjectMap::iterator itr = mObjectsByName.begin(); itr != mObjectsByName.end(); ++itr )
+        for (auto & itr : mObjectsByName)
         {
-            (*itr)->_notifyAttached((SceneNode*)0);
+            itr->_notifyAttached((SceneNode*)0);
         }
         mObjectsByName.clear();
         // Make sure bounds get updated (must go right to the top)
