@@ -45,8 +45,8 @@ namespace Ogre {
     {
         HighLevelGpuProgram::prepareImpl();
 
-        const String& target = getTarget();
-        uint32 seed = FastHash(target.c_str(), target.length());
+        mSyntaxCode = getTarget();
+        uint32 seed = FastHash(mSyntaxCode.c_str(), mSyntaxCode.length());
         uint32 hash = _getHash(seed);
         if ( GpuProgramManager::getSingleton().isMicrocodeAvailableInCache(hash) )
         {
@@ -108,13 +108,13 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     const String& D3D9HLSLProgram::getTarget() const
     {
-        if(mTarget.empty())
+        if(mSyntaxCode == "hlsl")
         {
             static String vs_2_0 = "vs_2_0", ps_2_0 = "ps_2_0";
             return mType == GPT_VERTEX_PROGRAM ? vs_2_0 : ps_2_0;
         }
 
-        return mTarget;
+        return mSyntaxCode;
     }
 
     void D3D9HLSLProgram::compileMicrocode(void)
@@ -184,7 +184,7 @@ namespace Ogre {
             pDefines,
             NULL,
             mEntryPoint.c_str(),
-            getTarget().c_str(),
+            mSyntaxCode.c_str(),
             compileFlags,
             &mMicroCode,
             &errors,
@@ -570,14 +570,6 @@ namespace Ogre {
         }
     }
     //-----------------------------------------------------------------------
-    bool D3D9HLSLProgram::isSupported(void) const
-    {
-        if (mCompileError || !isRequiredCapabilitiesSupported())
-            return false;
-
-        return GpuProgramManager::getSingleton().isSyntaxSupported(getTarget());
-    }
-    //-----------------------------------------------------------------------
     GpuProgramParametersSharedPtr D3D9HLSLProgram::createParameters(void)
     {
         // Call superclass
@@ -599,12 +591,12 @@ namespace Ogre {
             String & currentProfile = profiles[i];
             if(GpuProgramManager::getSingleton().isSyntaxSupported(currentProfile))
             {
-                mTarget = currentProfile;
+                mSyntaxCode = currentProfile;
                 return;
             }
         }
 
-        mTarget = profiles.front();
+        mSyntaxCode = profiles.front();
     }
 
     //-----------------------------------------------------------------------
