@@ -363,6 +363,9 @@ namespace Ogre {
             if(belowVersionPos != 0)
                 mSource = mSource.erase(0, belowVersionPos); // drop old definition
 
+            if(mSource.find("out vec4") == String::npos && mType == GPT_FRAGMENT_PROGRAM)
+                mSource.insert(0, "#define gl_FragColor FragColor\nout vec4 FragColor;\n");
+
             // automatically upgrade to glsl150. thank you apple.
             const char* prefixFp =
                     "#version 150\n"
@@ -374,9 +377,7 @@ namespace Ogre {
                     "#define texture2DLod textureLod\n"
                     "#define texture2DProj textureProj\n"
                     "#define textureCubeLod textureLod\n"
-                    "#define shadow2DProj textureProj\n"
-                    "#define gl_FragColor FragColor\n"
-                    "out vec4 FragColor;\n";
+                    "#define shadow2DProj textureProj\n";
             const char* prefixVp =
                     "#version 150\n"
                     "#define attribute in\n"
@@ -653,11 +654,8 @@ namespace Ogre {
 
 
         // Also parse any attached sources.
-        for (GLSLProgramContainer::const_iterator i = mAttachedGLSLPrograms.begin();
-             i != mAttachedGLSLPrograms.end(); ++i)
+        for (auto childShader : mAttachedGLSLPrograms)
         {
-            GLSLShaderCommon* childShader = *i;
-
             GLSLProgramManager::getSingleton().extractUniformsFromGLSL(
                 childShader->getSource(), *mConstantDefs, childShader->getName());
         }
