@@ -31,6 +31,7 @@ THE SOFTWARE.
 
 #include "VisualTest.h"
 #include "SamplePlugin.h"
+#include "SdkSample.h"
 
 using namespace Ogre;
 
@@ -785,6 +786,18 @@ protected:
 
 };
 
+class PlayPen_TwoSidedLighting : public VisualTest
+{
+public:
+
+    PlayPen_TwoSidedLighting();
+
+protected:
+
+    void setupContent();
+
+};
+
 //------------------------------------------------------------------------------
 /** Tests DXT1 loading */
 class _OgreSampleClassExport PlayPen_Dxt1 : public VisualTest
@@ -1583,6 +1596,16 @@ public:
 protected:
     void setupContent();
 };
+
+class _OgreSampleClassExport PlayPen_PBR : public OgreBites::SdkSample
+{
+public:
+    PlayPen_PBR();
+
+protected:
+    void setupContent();
+    void unloadResources();
+};
 //------------------------------------------------------------------------------
 
 // some common tasks for these tests:
